%This matlab file reads the data generated by the Analysis Sequences
%in the DemoModels and plots the comparisons between Coustyx results 
%and Analytical results.

%********************************************************************
%Compare results from coustyx and analytical solutions for 
%a rigid cylinder acoustic problem with a monopole source inside

%********************************************************************
%Input:
%  Run the following Analysis Sequences in the Demo Model,
%  before running this matlab script. 
%   (1) RunValidation - FMM
%********************************************************************
resultsFMM = load('validation_results_fmm.txt');

%  Each *.txt results file has 5 columns, where
%    results(:,1) = z, z coordinate of the observation point 
%                  (0.849,pi/4,z) in cylindrical coords
%    results(:,2) = Real part of coustyx field point pressure
%    results(:,3) = Imaginary part of coustyx field point pressure
%    results(:,4) = Real part of analytical pressure
%    results(:,5) = Imaginary part of analytical pressure

%********************************************************************

%********************************************************************
%Output:
%  (1) plot 1: Plots comparisons between FMM and Analytical results
%********************************************************************

%Acoustic medium properties:
%  rho_o = medium density of air = 1.21 
%  c = speed of sound = 343 
%  b0 = monopole volume velocity = 1
%  Freq = frequency of analysis = 200 Hz 
rho_o = 1.21;
c = 343;
bo = 1;
Freq = 200;
k = 2*pi*Freq/c;
P0 = abs(i*k*rho_o*c*bo);

%********************************************************************
%Plot FMM and Analytical results
%********************************************************************
figure;
plot(resultsFMM(:,1),abs(resultsFMM(:,2)+i*resultsFMM(:,3))/P0,'r-',...
    resultsFMM(:,1),abs(resultsFMM(:,4)+i*resultsFMM(:,5))/P0,'b.');
legend('Coustyx-FMM','Analytical');
title('Field point pressures per unit monopole strength - Amplitude');
xlabel('z, m');
ylabel('p/P0');

matFMM = [resultsFMM(:,1) (abs(resultsFMM(:,2)+i*resultsFMM(:,3))/P0) (abs(resultsFMM(:,4)+i*resultsFMM(:,5))/P0)];
%save results_abs_fmm.txt matFMM -ASCII







